#!/bin/sh
# chkconfig: 2345 99 33
# description: SNARE System iNtrusion Analysis and Reporting Environment
# processname: snaresquid
# config: /etc/snare/epilog/squid.conf
########################################################################
#
#   (c) 2001-2006 Intersect Alliance Pty Ltd
#
#   This script controls SnareSquid for UNIX
#
#   Version 1.1
#
#   Usage: /etc/init.d/snaresquidd { start | stop | restart } 
#
########################################################################

case "$1" in
'start')
        PID=`cat /var/run/snaresquid.pid 2>/dev/null`
        if [ ! -z "$PID" ] ;  then
		echo "SnareSquid already running. Please stop SnareSquid first."
		exit 1
	fi

	id | grep '^uid=0' > /dev/null
	if [ $? -ne 0 ]; then
		echo "Sorry, you need to be root to start snaresquid."
		exit 1
	fi

        if [ -f /usr/bin/snaresquid ] ; then
                echo "SnareSquid starting."
		/usr/bin/snaresquid -c /etc/snare/epilog/squid.conf
        fi
	exit 0
        ;;
'stop')
	id | grep '^uid=0' > /dev/null
	if [ $? -ne 0 ]; then
		echo "Sorry, you need to be root to start snaresquid."
		exit 1
	fi

        PID=`cat /var/run/snaresquid.pid 2>/dev/null`
       	if [ ! -z "$PID" ] ;  then
		kill -USR1 ${PID}
		sleep 1
		kill ${PID}
	fi
	rm -f /var/run/snaresquid.pid 2>/dev/null
	sleep 1

	# Just in case:
	# Kill all snaresquid processes, sorted on parent process ID
	# This way snaresquid with ppid of 1 gets killed first
        ps -e -u 0 -o "pid,ppid,comm"|grep "snaresquid" |grep -v grep|egrep -v snaresquid[d_]|sort -n +1|awk '{print $1}' |
		while read pid ppid command; do
			if [ ! -z "$pid" ] ; then
				echo "Cleaning up snaresquid process $pid"
				kill ${pid} 1>/dev/null 2>&1
			fi
		done
	exit 0
        ;;
'restart')
        if [ -f /etc/init.d/snaresquidd ] ; then
		/etc/init.d/snaresquidd stop
		RC=$?
		if [ $RC -gt 0 ]; then
			exit $RC
		fi
		/etc/init.d/snaresquidd start
		RC=$?
		if [ $RC -gt 0 ]; then
			exit $RC
		fi
	fi
	;;
	
*)
        echo 'Usage: /etc/init.d/snaresquidd { start | stop | restart }'
        ;;
esac

exit 0
